Class: JustCheckers::PieceMustCaptureError
- Defined in:
- lib/just_checkers/errors/piece_must_capture_error.rb
Overview
PieceMustCaptureError
A piece must capture error with a message
Instance Method Summary collapse
-
#initialize(message = "Another piece must capture first.") ⇒ PieceMustCaptureError
constructor
New piece must capture errors can be instantiated with.
Constructor Details
#initialize(message = "Another piece must capture first.") ⇒ PieceMustCaptureError
New piece must capture errors can be instantiated with
Example:
# Instantiates a new PieceMustCaptureError
JustCheckers::PieceMustCaptureError.new("Custom Message")
18 19 20 |
# File 'lib/just_checkers/errors/piece_must_capture_error.rb', line 18 def initialize(="Another piece must capture first.") super end |